@@ -6,7 +6,7 @@ from nonebot.adapters.onebot.v11 import Message, MessageSegment
 from nonebot.params import Arg, CommandArg, ArgPlainText, RawCommand
 from .drawer import get_token, get_taskId, get_img
 
-drawer = on_command("画画", aliases={"绘画", '油画', '水彩画', '卡通画', '粉笔画', '儿童画', '蜡笔画'}, priority=5)
+drawer = on_command("画画", aliases={'油画', '水彩画', '卡通画', '粉笔画', '儿童画', '蜡笔画'}, priority=5)
 
 
 @drawer.handle()
@@ -15,7 +15,7 @@ async def handle_first_receive(matcher: Matcher, command = RawCommand(), args =
     print(command) # 匹配结果
     print(args)
     print("##############")
-    if  "帮助" in str(command):
+    if  command == '画画': 
         help_msg = '当前支持油画、水彩画、卡通画、粉笔画、儿童画、蜡笔画\n主要擅长风景写意画，请尽量给定比较明确的意象\n如：油画 江上落日与晚霞'
         await matcher.finish(help_msg)
         
